<?php
/**
 * Japanese PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Mitsuhiro Yoshida <http://mitstek.com/>
 * @author Yoshi Sakai <http://bluemooninc.jp/>
 */

$PHPMAILER_LANG['authenticate']         = 'SMTPエラー: 認証できませんでした。';
$PHPMAILER_LANG['connect_host']         = 'SMTPエラー: SMTPホストに接続できませんでした。';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTPエラー: データが受け付けられませんでした。';
//$PHPMAILER_LANG['empty_message']        = 'Message body empty';
$PHPMAILER_LANG['encoding']             = '不明なエンコーディング: ';
$PHPMAILER_LANG['execute']              = '実行できませんでした: ';
$PHPMAILER_LANG['file_access']          = 'ファイルにアクセスできません: ';
$PHPMAILER_LANG['file_open']            = 'ファイルエラー: ファイルを開けません: ';
$PHPMAILER_LANG['from_failed']          = 'Fromアドレスを登録する際にエラーが発生しました: ';
$PHPMAILER_LANG['instantiate']          = 'メール関数が正常に動作しませんでした。';
//$PHPMAILER_LANG['invalid_address']      = 'Invalid address: ';
$PHPMAILER_LANG['provide_address']      = '少なくとも1つメールアドレスを 指定する必要があります。';
$PHPMAILER_LANG['mailer_not_supported'] = ' メーラーがサポートされていません。';
$PHPMAILER_LANG['recipients_failed']    = 'SMTPエラー: 次の受信者アドレスに 間違いがあります: ';
//$PHPMAILER_LANG['signing']              = 'Signing Error: ';
//$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP Connect() failed.';
//$PHPMAILER_LANG['smtp_error']           = 'SMTP server error: ';
//$PHPMAILER_LANG['variable_set']         = 'Cannot set or reset variable: ';
//$PHPMAILER_LANG['extension_missing']    = 'Extension missing: ';
