/*
 * Copyright 2005-2016 OCSInventory-NG/OCSInventory-ocsreports contributors.
 * See the Contributors file for more details about them.
 *
 * This file is part of OCSInventory-NG/OCSInventory-ocsreports.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the License,
 * or (at your option) any later version.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OCSInventory-NG/OCSInventory-ocsreports. if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */
.dynamic-slider-control {
    position:			relative;
    background-color:	#C7D9F5;
    -moz-user-focus:	normal;
    -moz-user-select:	none;
    cursor:				default;
}

.horizontal {
    width:				200px;
    height:				29px;
}

.vertical {
    width:				29px;
    height:				200px;
}

.dynamic-slider-control input {
    display:	none;
}

.dynamic-slider-control .handle {
    position:			absolute;
    -moz-user-select:	none;
    cursor:				default;
    background:			ThreeDFace;
    border:				1px solid;
    border-color:		ThreeDHighlight ThreeDDarkShadow
        ThreeDDarkShadow ThreeDHighlight;
}

/* inner border */
.dynamic-slider-control .handle div {
    font-size:			1px;
    border:				1px solid;
    border-color:		ThreeDLightShadow ThreeDShadow
        ThreeDShadow ThreeDLightShadow;	

    /*	behavior:			url("css/boxsizing.htc");	/* ie path bug */
    /*	box-sizing:			content-box;*/
    -moz-box-sizing:	content-box;
}

/*	inner sets size
.dynamic-slider-control.horizontal .handle {
    width:				12px;
    height:				22px;
}
*/

.dynamic-slider-control.horizontal .handle div {
    width:				8px;
    height:				18px;
}

.dynamic-slider-control.horizontal .handle.hover {}

/* inner sets size
.dynamic-slider-control.vertical .handle {
    width:				22px;
    height:				12px;
}
*/

.dynamic-slider-control.vertical .handle div {
    width:				18px;
    height:				8px;
}

.dynamic-slider-control.vertical .handle.hover {}

.dynamic-slider-control .line {

    /*	behavior:			url("css/boxsizing.htc"); /* ie path bug */
    /*	box-sizing:			content-box;*/
    -moz-box-sizing:	content-box;

    position:			absolute;
    font-size:			0.01mm;
    overflow:			hidden;
    border:				1px solid;
    border-color:		ThreeDShadow ThreeDHighlight
        ThreeDHighlight ThreeDShadow;
    background:			ThreeDDarkShadow;
}

.dynamic-slider-control.vertical .line {
    width:				1px;

}

.dynamic-slider-control.horizontal .line {
    height:				1px;
}

.dynamic-slider-control .line div {
    display:	none;
}