<?php
/**
 * Norwegian Bokmål PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 */

$PHPMAILER_LANG['authenticate']         = 'SMTP Feil: Kunne ikke autentisere.';
$PHPMAILER_LANG['connect_host']         = 'SMTP Feil: Kunne ikke koble til SMTP tjener.';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTP Feil: Datainnhold ikke akseptert.';
$PHPMAILER_LANG['empty_message']        = 'Melding kropp tomt';
$PHPMAILER_LANG['encoding']             = 'Ukjent koding: ';
$PHPMAILER_LANG['execute']              = 'Kunne ikke utføre: ';
$PHPMAILER_LANG['file_access']          = 'Får ikke tilgang til filen: ';
$PHPMAILER_LANG['file_open']            = 'Fil Feil: Kunne ikke åpne filen: ';
$PHPMAILER_LANG['from_failed']          = 'Følgende Frå adresse feilet: ';
$PHPMAILER_LANG['instantiate']          = 'Kunne ikke initialisere post funksjon.';
$PHPMAILER_LANG['invalid_address']      = 'Ugyldig adresse: ';
$PHPMAILER_LANG['mailer_not_supported'] = ' sender er ikke støttet.';
$PHPMAILER_LANG['provide_address']      = 'Du må opppgi minst en mottakeradresse.';
$PHPMAILER_LANG['recipients_failed']    = 'SMTP Feil: Følgende mottakeradresse feilet: ';
$PHPMAILER_LANG['signing']              = 'Signering Feil: ';
$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP connect() feilet.';
$PHPMAILER_LANG['smtp_error']           = 'SMTP server feil: ';
$PHPMAILER_LANG['variable_set']         = 'Kan ikke skrive eller omskrive variabel: ';
$PHPMAILER_LANG['extension_missing']    = 'Utvidelse mangler: ';
