<?php
/**
 * Bosnian PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Ermin Islamagić <ermin@islamagic.com>
 */

$PHPMAILER_LANG['authenticate']         = 'SMTP Greška: Neuspjela prijava.';
$PHPMAILER_LANG['connect_host']         = 'SMTP Greška: Nije moguće spojiti se sa SMTP serverom.';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTP Greška: Podatci nisu prihvaćeni.';
$PHPMAILER_LANG['empty_message']        = 'Sadržaj poruke je prazan.';
$PHPMAILER_LANG['encoding']             = 'Nepoznata kriptografija: ';
$PHPMAILER_LANG['execute']              = 'Nije moguće izvršiti naredbu: ';
$PHPMAILER_LANG['file_access']          = 'Nije moguće pristupiti datoteci: ';
$PHPMAILER_LANG['file_open']            = 'Nije moguće otvoriti datoteku: ';
$PHPMAILER_LANG['from_failed']          = 'SMTP Greška: Slanje sa navedenih e-mail adresa nije uspjelo: ';
$PHPMAILER_LANG['recipients_failed']    = 'SMTP Greška: Slanje na navedene e-mail adrese nije uspjelo: ';
$PHPMAILER_LANG['instantiate']          = 'Ne mogu pokrenuti mail funkcionalnost.';
$PHPMAILER_LANG['invalid_address']      = 'E-mail nije poslan. Neispravna e-mail adresa: ';
$PHPMAILER_LANG['mailer_not_supported'] = ' mailer nije podržan.';
$PHPMAILER_LANG['provide_address']      = 'Definišite barem jednu adresu primaoca.';
$PHPMAILER_LANG['signing']              = 'Greška prilikom prijave: ';
$PHPMAILER_LANG['smtp_connect_failed']  = 'Spajanje na SMTP server nije uspjelo.';
$PHPMAILER_LANG['smtp_error']           = 'SMTP greška: ';
$PHPMAILER_LANG['variable_set']         = 'Nije moguće postaviti varijablu ili je vratiti nazad: ';
$PHPMAILER_LANG['extension_missing']    = 'Nedostaje ekstenzija: ';