<?php
/**
 * Romanian PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Alex Florea <alecz.fia@gmail.com>
 */

$PHPMAILER_LANG['authenticate']         = 'Eroare SMTP: Autentificarea a eșuat.';
$PHPMAILER_LANG['connect_host']         = 'Eroare SMTP: Conectarea la serverul SMTP a eșuat.';
$PHPMAILER_LANG['data_not_accepted']    = 'Eroare SMTP: Datele nu au fost acceptate.';
$PHPMAILER_LANG['empty_message']        = 'Mesajul este gol.';
$PHPMAILER_LANG['encoding']             = 'Encodare necunoscută: ';
$PHPMAILER_LANG['execute']              = 'Nu se poate executa următoarea comandă:  ';
$PHPMAILER_LANG['file_access']          = 'Nu se poate accesa următorul fișier: ';
$PHPMAILER_LANG['file_open']            = 'Eroare fișier: Nu se poate deschide următorul fișier: ';
$PHPMAILER_LANG['from_failed']          = 'Următoarele adrese From au dat eroare: ';
$PHPMAILER_LANG['instantiate']          = 'Funcția mail nu a putut fi inițializată.';
$PHPMAILER_LANG['invalid_address']      = 'Adresa de email nu este validă: ';
$PHPMAILER_LANG['mailer_not_supported'] = ' mailer nu este suportat.';
$PHPMAILER_LANG['provide_address']      = 'Trebuie să adăugați cel puțin o adresă de email.';
$PHPMAILER_LANG['recipients_failed']    = 'Eroare SMTP: Următoarele adrese de email au eșuat: ';
$PHPMAILER_LANG['signing']              = 'A aparut o problemă la semnarea emailului. ';
$PHPMAILER_LANG['smtp_connect_failed']  = 'Conectarea la serverul SMTP a eșuat.';
$PHPMAILER_LANG['smtp_error']           = 'Eroare server SMTP: ';
$PHPMAILER_LANG['variable_set']         = 'Nu se poate seta/reseta variabila. ';
$PHPMAILER_LANG['extension_missing']    = 'Lipsește extensia: ';
