/*
 * Copyright 2005-2016 OCSInventory-NG/OCSInventory-ocsreports contributors.
 * See the Contributors file for more details about them.
 *
 * This file is part of OCSInventory-NG/OCSInventory-ocsreports.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the License,
 * or (at your option) any later version.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OCSInventory-NG/OCSInventory-ocsreports. if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */
.header-logo {
    padding-top: 3px;
    padding-bottom: 0;
}
.header-logo img{
    height: 40px;
    width: auto;
}

.navbar #log_out{
    display: none;
}

/*** OVERRIDE BOOTSTRAP ***/
.navbar-default{
    background-color: #fff !important;
    box-shadow: none !important;
    background-image: none;
}

.main-menu-container {
    margin-left: 137px;
}

.main-menu-container .navbar {
    margin-bottom: 10px;
}

.main-menu-container .navbar-nav > li {
    float: none;
    display: inline-block;
}

.main-menu-container .navbar-nav > li > a {
    padding-top: 14px;
    padding-bottom: 14px;
}

.user-header {
    background: black;
    color: white;
    min-height: 15px;
}

.user-header .version,
.user-header .links {
    float: right;
    margin: 0 10px
}

.user-header .links > * {
    margin: 0 10px;
    color: white;
    float: right;
}

#menu_settings{
    font-size:20px;
}