-- Create snmpmibs if not already exists
CREATE TABLE IF NOT EXISTS `repository` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `HARDWARE_ID` INT(11) NOT NULL,
    `BASEURL` VARCHAR(255) DEFAULT NULL,
    `EXCLUDE` VARCHAR(255) DEFAULT NULL,
    `EXCLUDED` VARCHAR(255) DEFAULT NULL,
    `EXPIRE` VARCHAR(255) DEFAULT NULL,
    `FILENAME` VARCHAR(255) DEFAULT NULL,
    `MIRRORS` VARCHAR(255) DEFAULT NULL,
    `NAME` VARCHAR(255) DEFAULT NULL,
    `PKGS` VARCHAR(255) DEFAULT NULL,
    `REVISION` VARCHAR(255) DEFAULT NULL,
    `SIZE` VARCHAR(255) DEFAULT NULL,
    `TAG` VARCHAR(255) DEFAULT NULL,
    `UPDATED` VARCHAR(255) DEFAULT NULL,
    PRIMARY KEY (`ID`)
) ENGINE=InnoDB DEFAULT CHARSET=UTF8;