<?php
/**
 * Spanish PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Matt Sturdy <matt.sturdy@gmail.com>
 */

$PHPMAILER_LANG['authenticate']         = 'Error SMTP: Imposible autentificar.';
$PHPMAILER_LANG['connect_host']         = 'Error SMTP: Imposible conectar al servidor SMTP.';
$PHPMAILER_LANG['data_not_accepted']    = 'Error SMTP: Datos no aceptados.';
$PHPMAILER_LANG['empty_message']        = 'El cuerpo del mensaje está vacío.';
$PHPMAILER_LANG['encoding']             = 'Codificación desconocida: ';
$PHPMAILER_LANG['execute']              = 'Imposible ejecutar: ';
$PHPMAILER_LANG['file_access']          = 'Imposible acceder al archivo: ';
$PHPMAILER_LANG['file_open']            = 'Error de Archivo: Imposible abrir el archivo: ';
$PHPMAILER_LANG['from_failed']          = 'La(s) siguiente(s) direcciones de remitente fallaron: ';
$PHPMAILER_LANG['instantiate']          = 'Imposible crear una instancia de la función Mail.';
$PHPMAILER_LANG['invalid_address']      = 'Imposible enviar: dirección de email inválido: ';
$PHPMAILER_LANG['mailer_not_supported'] = ' mailer no está soportado.';
$PHPMAILER_LANG['provide_address']      = 'Debe proporcionar al menos una dirección de email de destino.';
$PHPMAILER_LANG['recipients_failed']    = 'Error SMTP: Los siguientes destinos fallaron: ';
$PHPMAILER_LANG['signing']              = 'Error al firmar: ';
$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP Connect() falló.';
$PHPMAILER_LANG['smtp_error']           = 'Error del servidor SMTP: ';
$PHPMAILER_LANG['variable_set']         = 'No se pudo configurar la variable: ';
$PHPMAILER_LANG['extension_missing']    = 'Extensión faltante: ';
