/*
 * Copyright 2005-2016 OCSInventory-NG/OCSInventory-ocsreports contributors.
 * See the Contributors file for more details about them.
 *
 * This file is part of OCSInventory-NG/OCSInventory-ocsreports.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the License,
 * or (at your option) any later version.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OCSInventory-NG/OCSInventory-ocsreports. if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */
/* OCSReports Style Sheet */
table.qr
{
    border-collapse: collapse;
    border: solid 1px black;
    table-layout: fixed;
}

table.qr td
{
    width: 5px;
    height: 5px;
    font-size: 2px;
}

table.qr td.on
{
    background: #000000;
}
.fond{
    width:97%;
    margin:auto;
}

.conteneur {
    /*background-color: #C7D9F5;*/
    position: absolute;
    left: 30px;
    /*vertical-align:center; */
}

html,body{
    text-align: center;
    font-size: 12px;
    height:100%;
}

.fondu {
    background-image: url(../image/fond.png);
    width:100%;
    background-position : top center ;
    background-repeat: no-repeat;
    background-attachment: fixed;
}


a, img, .lienBleu, .norm, td, b,.warn {
    text-decoration: none;
    border-width: 0px;
    font-size: 12px;
}

.warn {
    font-size: 14px;
    color: red;
    font-weight:bold;
}

a,a:visited, .lienBleu {
    cursor: pointer;
    /*color: #3151CD;*/
}

a.btn-success{
    color: white;
}

a.deco {
    color:#C7D9F5;
    font-size: 8pt;
}

a img {
    vertical-align: middle;
}

.lienBleu  {
    color: blue;
}

option.hi {
    background-color:#FFFFFF;
}

.Items {
    border-width: 2px;
    border-bottom-color:#666666;
    border-left-color:#D6D6D6;
    border-right-color:#666666;
    border-top-color:#D6D6D6;
}

.textbox
{
    border: thin solid;
}

table.Erreur
{
    border-color: #A1B1F9;
    border-spacing: 0px;
    border-style: solid;
    border-width: 2px;
    border-collapse: collapse;
}

th.Erreur
{
    background-color: #C7D9F5;
    border-bottom-color: #A1B1F9;
    border-bottom-style: solid;
    border-bottom-width: 2px;
    border-collapse: collapse;
}

td.Machine
{
    vertical-align:top ;
    font-size:8pt;
}

td#color
{
    background-color:#C7D9F5 ;
}

td#type
{
    font-family:Tahoma;
    font-size:8pt;
    text-align:center;
    font-weight:bold;
}

table.Fenetre, table.Main
{
    background-color: white;
    border-color: #A1B1F9;
    border-spacing: 0px;
    border-style: solid;
    border-width: 2px;
    border-collapse: collapse;
}

table.Fenetre
{
    width:62%;
}

table.Main
{
    width:95%;
}


table.headfoot
{
    background-color: #f2f2f2;
    border-color: #000000;
    border-spacing: 0px;
    border-style: solid;
    border-width: 1px;
    border-collapse: collapse;
    width:100%;
}


select.ge {
    background-color: #C7D9F5;
    height: 246px;
    width: 350px;
}

.boutonP {
    background-color: #C7D9F5;
    border-color: #A1B1F9;
    border-style: solid;
    border-width: 1px;
    cursor: pointer;
    font-size: 8pt;
}

.boutonG {
    background-color: #C7D9F5;
    border-color: #A1B1F9;
    border-style: solid;
    border-width: 1px;
    cursor: pointer;
}

.Lien {
    border-left-color: #FFFFFF;
    border-bottom-color: #FFFFFF;
    border-top-color: #FFFFFF;
    border-right-color: #FFFFFF;
}

.Main {
    cursor: pointer;
}

#fenetre
{
    position: absolute;
    top: 20%;
    left: 30%;
}

#search {
    border-collapse: collapse;
    width: 240px;
}

dl, dt, dd, ul, li {
    margin: 0;
    padding: 0;
    list-style-type: none;
}

#menu dt {
    cursor: pointer;
    margin: 2px 0;
    text-align: center;
    font-weight: bold;
}

#menu dd {
    position: absolute;
    z-index: 100;
    margin-top: 5px ;
    width: 17em;
    background: #D6DCF2;
    border: 1px solid gray;
    border-radius: 1em;
    -webkit-border-radius: 1em;
}

#menu ul {
    padding: 2px;
}
#menu li {
    text-align: center;
    font-size: 85%;
    line-height: 18px;
}
#menu li a, #menu dt a {
    color: #000;
    text-decoration: none;
    display: block;
}

#menu li a:hover {
    text-decoration: underline;
}

table.ta {
    width: 99%;		/*100% of container produces horiz. scroll in Mozilla*/
    /*border: 1px slategray;*/
    border-bottom: solid 1px #9894B5;
    border-top: solid 1px #9894B5;
    border-left: solid 1px #9894B5;
    border-right:solid 1px #9894B5;

}

tbody.ta	{  /* child selector syntax which IE6 and older do not support*/
    overflow: auto;
    overflow-x: hidden;
}

th.ta	{
    font-size: 20px;
    font-weight: bold;
    text-align: center;
    width: 50px;
    background-color: #E0E2E2;
    color: steelblue;
    /*border: solid slategray thin;*/
    /*border-left: solid 1px slategray;*/
    border-bottom: solid 1px #9894B5;
    border-top: solid 1px #9894B5;
    border-left: solid 1px #9894B5;
    position:relative;
    /*top: expression(document.getElementById('data').scrollTop-2); /*IE5+ only*/
}

tr.ta {
    text-align: center;
    border-right:solid 1px #9894B5;
}

td.ta	{
    color: #000;
    text-align: center;
    /*padding-right: 2px;*/
    font-size: 12px;
    font-family: Arial,sans-serif;
    border-bottom: solid 1px #9894B5;
    border-left: solid 1px #9894B5;
}

td.ta:last-child {border-right: solid 1px #9894B5;} /*prevent Mozilla scrollbar from hiding cell content*/
th.ta:last-child {border-right: solid 1px #9894B5;}

.mlt_bordure {
    margin:0 auto 0 auto;
    background: #f8f8f8;
    border: 1px solid #c7c7c7;
    padding: 20px 50px;
    margin-bottom: 20px;
    text-align: center;
}

.mvt_bordure {
    display: inline-block;
    background: #f8f8f8;
    border: 1px solid #c7c7c7;
    padding: 20px 50px;
    margin-bottom: 20px;
    text-align: center;
}

.mvt_tab {
    margin:0 auto 0 auto;
    border-radius: 1em;
    -webkit-border-radius: 1em;
    padding: 10px;
}

.image{
    background-color:#D6DCF2;
}


/* see => http:\\dmouronval.developpez.com\tutoriels\css\messages-personnalises\ */
/* tx to Knob-Buttons-Toolbar-icons => http:\\itweek.deviantart.com\art\Knob-Buttons-Toolbar-icons-73463960 */


.info, .success, .warning, .error, .validation {
    width:50%;
    border: 1px solid;
    margin: 10px auto;
    padding:15px 10px 15px 50px;
    background-repeat: no-repeat;
    background-position: 10px center;
}
.info {
    color: #00529B;
    background-color: #BDE5F8;
    background-image: url('../image/info.png');
}
.success {
    color: #4F8A10;
    background-color: #DFF2BF;
    background-image:url('../image/success.png');
}
.warning {
    color: #9F6000;
    background-color: #FEEFB3;
    background-image: url('../image/warning.png');
}
.error {
    color: #D8000C;
    background-color: #FFBABA;
    background-image: url('../image/error.png');
}

.validation {
    color: #D63301;
    background-color: #FFCCBA;
    background-image: url('../image/validation.png');
}

.tooltip{
    position: absolute;
    visibility : hidden;
    border: 1px solid Black;
    padding: 10px;
    font-size: 10px;
    background-color: #FFFFCC;
}


.comment_after{
    float:right;
}

iframe{
    width:100%;
    height:100%;
    border:none;
    margin:auto;
    position:relative;
}

.iframe_div{
    width:80%;
    height:70%;
    margin:0 auto 0 auto;
}

.iframe_link{
    color: rgb(116, 116, 116)!important;
    font-weight: bold;
    text-decoration: none
}

.navbar-left li{
    text-align: left;
}
/*.navbar-left li a{
    color: #777;
}
*/
/*** CONTENT ***/
.right-content {
    margin-left: 190px;
    margin-right: 20px;
}

.server-information-ul{
    font-weight: bold;
    text-align: left;
}
.server-information-ul-li{
    text-align: left;
}

/*.profile-img {
    width: auto;
    height: 256px;
    margin: 0 auto 10px;
    display: block;
}*/
.config-row > .col-md-6{
    text-align: left;
}
.delete-span{
    color: rgba(193, 46, 42, 1);
    font-weight: bold;
    font-size: xx-large;
}
.delete-span:hover{
    color: rgba(193, 46, 42, 0.8);
}

.delete-span-xs{
    font-size: medium;
}

.margin-top30{
    margin-top: 30px;
}

.rowMarginTop30{
    margin-top: 30px;
}

.roundRed{
    display: inline-block;
    vertical-align: middle;
    height: 15px;
    width: 15px;
    border-radius: 100%;
    background: rgba(193, 46, 42, 1);
}

.spaceX-10-right{
    margin-right: 10px;
}

.span-charts ul li span{
    height: 10px;
    width: 10px;
    display: inline-block;
    position: relative;
}
