/*
 * Copyright 2005-2016 OCSInventory-NG/OCSInventory-ocsreports contributors.
 * See the Contributors file for more details about them.
 *
 * This file is part of OCSInventory-NG/OCSInventory-ocsreports.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the License,
 * or (at your option) any later version.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OCSInventory-NG/OCSInventory-ocsreports. if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */
.right-caret {
    display: inline-block;
    width: 0;
    height: 0;
    float: right;
    margin: 6px 0;
    vertical-align: middle;
    border-bottom: 4px solid transparent;
    border-top: 4px solid transparent;
    border-left: 4px solid;
}


/*** SUMMARY ***/

.summary {
    width: 100%;
    text-align: left;
}

.summary-row:first-child {
    border-top: 1px solid #c7c7c7;
}

.summary-cell {
    width: 50%;
    padding: 5px 10px 10px 20px;
    border: 1px solid #c7c7c7;
    vertical-align: top;
}

.summary-header {
    display: inline-block;
    font-weight: bold;
    width: 30%;
    padding: 3px 0;
}

.summary-value {
    display: inline-block;
    width: 70%;
    padding: 3px 0;
}

/*** PLUGINS ***/

.plugin-frame {
    background: #f8f8f8;
    border: 1px solid #c7c7c7;
    padding: 10px;
    margin-bottom: 20px;
}
