/*
 * Copyright 2005-2016 OCSInventory-NG/OCSInventory-ocsreports contributors.
 * See the Contributors file for more details about them.
 *
 * This file is part of OCSInventory-NG/OCSInventory-ocsreports.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the License,
 * or (at your option) any later version.
 *
 * OCSInventory-NG/OCSInventory-ocsreports is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OCSInventory-NG/OCSInventory-ocsreports. if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */
/* Percent bar */
div.percent_bar { height:14px; width:102px; text-align:left; border:1px solid #808080; border-radius:3px; }
div.percent_status { height:12px; position:absolute; z-index:1; background-color:#4BBA25;font-size:1px; border:1px solid #FFFFFF; border-radius:3px; }
div.percent_text { height:12px; position:absolute; z-index:2; width:100px; font-size:11px;
                   text-align:center; font-family:arial; color:#000000;
                   font-weight:bold; }